@@ -76,7 +76,8 @@ class OnesaitPlatformArtifactRepository(ArtifactRepository):
             parameter_key = 'params.{}{}'.format(
                 ARTIFACTS_PARAM_KEY, str(artifact_index)
                 )
-            if parameter_key in run.columns:
+            if parameter_key in run.columns and\
+               run[parameter_key].tolist()[0] is not None:
                 artifact_info = run[parameter_key].tolist()[0]
                 try:
                     artifact_info = json.loads(artifact_info)
